@@ -13,6 +13,11 @@ from LanguageSelector.LanguageSelector import *
 from QtLanguageSelectorGUI import Ui_QtLanguageSelectorGUI
 from gettext import gettext as i18n
 
+def utf8(str):
+  if isinstance(str, unicode):
+      return str
+  return unicode(str, 'UTF-8')
+
 def _(string):
     return unicode(i18n(string), "utf-8")
 
@@ -61,7 +66,7 @@ class QtLanguageSelector(QWidget,LanguageSelectorBase):
         try:
             self.openCache(apt.progress.OpProgress())
         except ExceptionPkgCacheBroken:
-            s = _("Software database is broken"),
+            s = _("Software database is broken")
             # FIXME: mention adept here instead of synaptic, but the
             #        change happend during string freeze
             t = _("It is impossible to install or remove any software. "
@@ -92,7 +97,7 @@ class QtLanguageSelector(QWidget,LanguageSelectorBase):
             defaultLangName = self._localeinfo.translate(defaultLangCode)
         locales = []
         for locale in self._localeinfo.generated_locales():
-            name = self._localeinfo.translate(locale)
+            name = utf8(self._localeinfo.translate(locale))
             locales.append(name)
             self._localeinfo.localeToCodeMap[name] = locale
         locales.sort()
@@ -116,7 +121,7 @@ class QtLanguageSelector(QWidget,LanguageSelectorBase):
 
         for langName in languages:
             lang = self._localeinfo.listviewStrToLangInfoMap[langName]
-            elm = QListWidgetItem(lang.language, self.ui.listViewLanguages)
+            elm = QListWidgetItem(utf8(lang.language), self.ui.listViewLanguages)
             if lang.langPackInstalled and lang.langSupportInstalled:
                 if self.mode == "install":
                     elm.setFlags(Qt.ItemIsDropEnabled)  #not sure how to unset all flags, but this disables the item
@@ -228,7 +233,7 @@ class QtLanguageSelector(QWidget,LanguageSelectorBase):
         items = self.ui.listViewLanguages.selectedItems()
         if len(items) == 1:
             elm = items[0]
-            li = self._localeinfo.listviewStrToLangInfoMap["%s"%elm.text()]
+            li = self._localeinfo.listviewStrToLangInfoMap["%s"%elm.text().toUtf8()]
             if self.mode == "uninstall":
                 self._cache.tryRemoveLanguage(li.languageCode)
             else:
